@@ -150,10 +150,15 @@ impl<'c> Connection<'c> {
             Ok(None) => return Ok(None),
             Err(e) => return Err(e),
         };
+        // The rust compiler needs some help here. It assumes otherwise that the lifetime of the
+        // resulting cursor would depend on the lifetime of `params`.
         let cursor = ManuallyDrop::new(cursor);
         let handle = cursor.as_sys();
+        // Safe: `handle` is a valid statement, and we are giving up ownership of `self`.
         let statement = unsafe { StatementConnection::new(handle, self) };
-        Ok(Some(CursorImpl::new(statement)))
+        // Safe: `statement is in the cursor state`.
+        let cursor = unsafe { CursorImpl::new(statement) };
+        Ok(Some(cursor))
     }
 
     /// Prepares an SQL statement. This is recommended for repeated execution of similar queries.
@@ -454,10 +459,10 @@ impl<'c> Connection<'c> {
     ) -> Result<CursorImpl<StatementImpl<'_>>, Error> {
         let statement = self.allocate_statement()?;
 
-        let catalog_name = catalog_name.map(|s| U16String::from_str(s));
-        let schema_name = schema_name.map(|s| U16String::from_str(s));
-        let table_name = table_name.map(|s| U16String::from_str(s));
-        let table_type = table_type.map(|s| U16String::from_str(s));
+        let catalog_name = catalog_name.map(U16String::from_str);
+        let schema_name = schema_name.map(U16String::from_str);
+        let table_name = table_name.map(U16String::from_str);
+        let table_type = table_type.map(U16String::from_str);
         execute_tables(
             statement,
             catalog_name.as_deref(),
