@@ -15,6 +15,18 @@ impl<'o> Prepared<'o> {
         Self { statement }
     }
 
+    /// Transfer ownership to the underlying statement handle.
+    ///
+    /// The resulting type is one level of indirection away from the raw pointer of the ODBC API. It
+    /// no longer has any guarantees about bound buffers, but is still guaranteed to be a valid
+    /// allocated statement handle. This serves together with
+    /// [`crate::handles::StatementImpl::into_sys`] or [`crate::handles::Statement::as_sys`] this
+    /// serves as an escape hatch to access the functionality provided by `crate::sys` not yet
+    /// accessible through safe abstractions.
+    pub fn into_statement(self) -> StatementImpl<'o> {
+        self.statement
+    }
+
     /// Execute the prepared statement.
     ///
     /// * `params`: Used to bind these parameters before executing the statement. You can use `()`
