@@ -15,8 +15,8 @@ use odbc_api::{
     },
     handles::{OutputStringBuffer, Statement},
     parameter::{Blob, BlobRead, BlobSlice, VarBinaryArray, VarCharArray, VarCharSlice},
-    sys, ColumnDescription, Cursor, DataType, InputParameter, IntoParameter, Nullability, Nullable,
-    Out, ResultSetMetadata, U16String,
+    sys, ColumnDescription, Cursor, CursorImpl, DataType, InputParameter, IntoParameter,
+    Nullability, Nullable, Out, ResultSetMetadata, U16String,
 };
 use std::{
     convert::TryInto,
@@ -2704,6 +2704,46 @@ fn row_array_size_66536(profile: &Profile) {
     assert!(cursor.bind_buffer(row_set_buffer).is_ok())
 }
 
+#[test_case(MSSQL; "Microsoft SQL Server")]
+#[test_case(MARIADB; "Maria DB")]
+#[test_case(SQLITE_3; "SQLite 3")]
+fn execute_query_twice_with_different_args_by_modifying_bound_param_buffer(profile: &Profile) {
+    let table_name = "ExecuteQueryTwiceWithDifferentArgsByModifyingBoundParamBuffer";
+    let conn = profile
+        .setup_empty_table(table_name, &["INTEGER", "INTEGER"])
+        .unwrap();
+    let insert = format!("INSERT INTO {} (a,b) VALUES (1,1), (2,2);", table_name);
+    conn.execute(&insert, ()).unwrap();
+
+    let query = format!("SELECT a FROM {} WHERE b=?;", table_name);
+    let prepared = conn.prepare(&query).unwrap();
+
+    // Prepared statement has not yet any abstraction to keep parameters bound between execution.
+    let mut stmt = prepared.into_statement();
+
+    // Stack allocated parameter. Used for both query executions.
+    let mut b = 1;
+
+    let cursor = unsafe {
+        stmt.bind_input_parameter(1, &b);
+        stmt.execute();
+        CursorImpl::new(&mut stmt)
+    };
+
+    assert_eq!("1", cursor_to_string(cursor));
+
+    // Execute a second time, with a different argument, but without rebinding the parameter buffer.
+    b = 2;
+
+    let cursor = unsafe {
+        stmt.bind_input_parameter(1, &b);
+        stmt.execute();
+        CursorImpl::new(&mut stmt)
+    };
+
+    assert_eq!("2", cursor_to_string(cursor));
+}
+
 /// This test is inspired by a bug caused from a fetch statement generating a lot of diagnostic
 /// messages.
 #[test]
